# ChatGPT CLI Interface (based on LangChain)

As simple as possible ChatGPT CLI interface made with LangChain wrapper. 

Edit prompt templates using .yaml files. 

## Installation

```shell

pip install -r requirements.txt

```

## Usage

```shell

python app.py

```


